@@ -11,6 +11,11 @@ from logging import StreamHandler
 from logging.handlers import TimedRotatingFileHandler
 from pathlib import Path
 
+try:
+    import graypy
+except ImportError:
+    graypy = None
+
 from mxcubecore import (
     ColorFormatter,
 )
@@ -202,6 +207,24 @@ class MXCUBEApplication:
         MXCUBEApplication.beamline.init_signals()
         MXCUBEApplication.harvester.init_signals()
 
+    @staticmethod
+    def _get_graylog_handler(config, log_level):
+        if graypy is None:
+            return None
+        server_cfg = getattr(config, "server", None)
+        graylog_host = getattr(server_cfg, "GRAYLOG_HOST", None)
+        graylog_port = getattr(server_cfg, "GRAYLOG_PORT", None)
+        if graylog_host and graylog_port:
+            try:
+                handler = graypy.GELFUDPHandler(graylog_host, graylog_port)
+            except Exception as ex:
+                msg = "Graylog handler could not be initialized: " + str(ex)
+                logging.getLogger("HWR").info(msg)
+            else:
+                handler.setLevel(log_level)
+                return handler
+        return None
+
     @staticmethod
     def init_logging(log_file, log_level, enabled_logger_list):
         """
@@ -244,6 +267,9 @@ class MXCUBEApplication:
         custom_log_handler = MX3LoggingHandler(MXCUBEApplication.server)
         custom_log_handler.setLevel(log_level)
         custom_log_handler.setFormatter(file_formatter)
+        gelf_handler = MXCUBEApplication._get_graylog_handler(
+            MXCUBEApplication.CONFIG, log_level
+        )
 
         _loggers = {
             "hwr_logger": logging.getLogger("HWR"),
@@ -261,6 +287,8 @@ class MXCUBEApplication:
             if logger_name in enabled_logger_list:
                 logger.addHandler(custom_log_handler)
                 logger.addHandler(stdout_log_handler)
+                if gelf_handler:
+                    logger.addHandler(gelf_handler)
                 logger.setLevel(log_level)
 
                 if log_file and "mx3_ui" in logger_name:
