@@ -67,9 +67,7 @@ class Beamline(ComponentBase):
 
         pixelsPerMm = HWR.beamline.diffractometer.get_pixels_per_mm()
 
-        beam_info_dict = self.get_beam_info()
-
-        data = {
+        return {
             "pixelsPerMm": pixelsPerMm,
             "imageWidth": width,
             "imageHeight": height,
@@ -81,9 +79,6 @@ class Beamline(ComponentBase):
             "videoURL": self.app.CONFIG.app.VIDEO_STREAM_URL,
         }
 
-        data.update(beam_info_dict)
-        return data
-
     def beamline_get_all_attributes(self):
         ho = BeamlineAdapter(HWR.beamline)
         data = ho.dict()
@@ -154,12 +149,6 @@ class Beamline(ComponentBase):
 
         HWR.beamline.diffractometer.set_phase(phase)
 
-    def set_aperture(self, pos):
-        beam = HWR.beamline.beam
-        msg = "Changing beam size to: %s" % pos
-        logging.getLogger("MX3.HWR").info(msg)
-        beam.set_value(pos)
-
     def diffractometer_get_info(self):
         ret = {}
 
